{
  "type": "record",
  "Aspect": {
    "name": "dataHubConnectionDetails"
  },
  "name": "DataHubConnectionDetails",
  "namespace": "com.linkedin.pegasus2avro.connection",
  "fields": [
    {
      "Searchable": {},
      "type": {
        "type": "enum",
        "symbolDocs": {
          "JSON": "A json-encoded set of connection details"
        },
        "name": "DataHubConnectionDetailsType",
        "namespace": "com.linkedin.pegasus2avro.connection",
        "symbols": [
          "JSON"
        ]
      },
      "name": "type",
      "doc": "The type of the connection. This defines the schema / encoding of the connection details."
    },
    {
      "Searchable": {
        "boostScore": 10.0,
        "enableAutocomplete": true,
        "fieldType": "TEXT_PARTIAL"
      },
      "type": [
        "null",
        "string"
      ],
      "name": "name",
      "default": null,
      "doc": "Display name of the connection"
    },
    {
      "type": [
        "null",
        {
          "type": "record",
          "name": "DataHubJsonConnection",
          "namespace": "com.linkedin.pegasus2avro.connection",
          "fields": [
            {
              "type": "string",
              "name": "encryptedBlob",
              "doc": "The encrypted JSON connection details."
            }
          ],
          "doc": "A set of connection details consisting of an encrypted JSON blob."
        }
      ],
      "name": "json",
      "default": null,
      "doc": "An JSON payload containing raw connection details.\nThis will be present if the type is JSON."
    }
  ],
  "doc": "Information about a connection to an external platform."
}